/***************************************************************************//**
 *   @file   AD511X.h
 *   @brief  Header file of AD511X Driver.
 *   @author Dan Nechita
********************************************************************************
 * Copyright 2012(c) Analog Devices, Inc.
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *  - Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  - Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  - Neither the name of Analog Devices, Inc. nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *  - The use of this software may or may not infringe the patent rights
 *    of one or more patent holders.  This license does not release you
 *    from the requirement that you obtain separate licenses from these
 *    patent holders to use this software.
 *  - Use of the software either in source or binary form, must be run
 *    on or directly connected to an Analog Devices Inc. component.
 *
 * THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT,
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
********************************************************************************
 *   SVN Revision: 782
*******************************************************************************/
#ifndef __AD511X_H__
#define __AD511X_H__

/******************************************************************************/
/******************************** AD5110 **************************************/
/******************************************************************************/

/* Supported devices */
#define AD5110      0
#define AD5112      1
#define AD5114      2

/* End-to-end resistance of the device. */
#define AD511X_5_KOHM           5000    // Only for AD5112
#define AD511X_10_KOHM          10000   // AD5110, AD5112, AD5114 
#define AD511X_80_KOHM          80000   // AD5110, AD5112, AD5114 

/* Device Slave Address */
#define AD511X_SLAVE_ADDRESS           0x2F
#define AD511X_1_SLAVE_ADDRESS         0x2C

/* Input Shift Register definition. */
#define AD511X_COMMAND(x)       (((x) & 0x07) << 8)
#define AD511X_DATA(x)          (((x) & 0xFF) << 0)

/* AD511X_COMMAND(x) options. */
#define AD511X_NOP_CMD                      0
#define AD511X_WR_RDAC_TO_EEPROM_CMD        1
#define AD511X_WR_SERIAL_TO_RDAC_CMD        2
#define AD511X_SOFT_SHUTDOWN_CMD            3
#define AD511X_SOFT_RESET_CMD               4
#define AD511X_RD_RDAC_CMD                  5
#define AD511X_RD_EEPROM_CMD                6

/* AD511X_DATA(x) options when used in conjunction with some commands. */
/* AD511X_WR_SERIAL_TO_RDAC_CMD */
#define AD511X_DATA_TOP_SCALE               0x80
#define AD511X_DATA_BOTTOM_SCALE            0xFF

/* AD511X_SOFT_SHUTDOWN_CMD */
#define AD511X_DATA_SHUTDOWN_OFF            0
#define AD511X_DATA_SHUTDOWN_ON             1

/* AD511X_RD_EEPROM */
#define AD511X_DATA_WIPER_POS               0
#define AD511X_DATA_RESISTOR_TOL            1

/******************************************************************************/
/************************ Functions Declarations ******************************/
/******************************************************************************/

/*! Initializes the communication with the device. */
unsigned char AD511X_Init(char deviceModel, long endToEndRes);

/*! Sends a command to the device. */
void AD511X_SendCommand(unsigned char command, unsigned char data);

/*! Powers on/off the device. */
void AD511X_Power(char pwr);
    
/*! Reads data from the device. */    
unsigned char AD511X_ReadData(char readLocation, char content);    

/*! Performs an Acknowledge Polling. */
void AD511X_WaitForDevice(void);

/*! Reads the resistance tolerance that is stored in the internal memory during 
    factory testing. */
float AD511X_GetTolerance(void);

/*! Sets the output resistance of the device. */
float AD511X_SetResistance(float outRes);

#endif	// __AD511X_H__
